@@ -1,5 +1,5 @@
 /*
- * Copyright 2007-2021 The jdeb developers.
+ * Copyright 2007-2024 The jdeb developers.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -85,6 +85,11 @@ class ControlBuilder {
      * @throws java.text.ParseException
      */
     void buildControl(BinaryPackageControlFile packageControlFile, File[] controlFiles, List<String> conffiles, StringBuilder checksums, File output) throws IOException, ParseException {
+
+        if (packageControlFile == null) {
+            throw new FileNotFoundException("No 'control' file found in " + controlFiles.toString());
+        }
+
         final File dir = output.getParentFile();
         if (dir != null && (!dir.exists() || !dir.isDirectory())) {
             throw new IOException("Cannot write control file at '" + output.getAbsolutePath() + "'");
@@ -112,16 +117,22 @@ class ControlBuilder {
                 foundConffiles = true;
             }
 
+            if ("control".equals(file.getName())) {
+                continue;
+            }
+
             if (CONFIGURATION_FILENAMES.contains(file.getName()) || MAINTAINER_SCRIPTS.contains(file.getName())) {
+
                 FilteredFile configurationFile = new FilteredFile(new FileInputStream(file), resolver);
                 configurationFile.setOpenToken(openReplaceToken);
                 configurationFile.setCloseToken(closeReplaceToken);
                 addControlEntry(file.getName(), configurationFile.toString(), outputStream);
 
-            } else if (!"control".equals(file.getName())) {
+            } else {
+
                 // initialize the information stream to guess the type of the file
                 InformationInputStream infoStream = new InformationInputStream(new FileInputStream(file));
-                Utils.copy(infoStream, NullOutputStream.NULL_OUTPUT_STREAM);
+                Utils.copy(infoStream, NullOutputStream.INSTANCE);
                 infoStream.close();
 
                 // fix line endings for shell scripts
@@ -131,7 +142,7 @@ class ControlBuilder {
                     in = new ByteArrayInputStream(buf);
                 }
 
-                addControlEntry(file.getName(), IOUtils.toString(in), outputStream);
+                addControlEntry(file.getName(), IOUtils.toString(in, java.nio.charset.StandardCharsets.UTF_8), outputStream);
 
                 in.close();
             }
@@ -145,10 +156,6 @@ class ControlBuilder {
             console.info("Skipping 'conffiles' generation. No entries defined in maven/pom or ant/build.xml.");
         }
 
-        if (packageControlFile == null) {
-            throw new FileNotFoundException("No 'control' file found in " + controlFiles.toString());
-        }
-
         addControlEntry("control", packageControlFile.toString(), outputStream);
         addControlEntry("md5sums", checksums.toString(), outputStream);
 
@@ -215,6 +222,9 @@ class ControlBuilder {
 
 
     private void addControlEntry(final String pName, final String pContent, final TarArchiveOutputStream pOutput) throws IOException {
+
+        console.info("Adding control: " + pName);
+
         final byte[] data = pContent.getBytes(UTF_8);
 
         final TarArchiveEntry entry = new TarArchiveEntry("./" + pName, true);
