@@ -1,5 +1,5 @@
 /*
- * Copyright 2007-2021 The jdeb developers.
+ * Copyright 2007-2024 The jdeb developers.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,6 +22,7 @@ import org.apache.commons.compress.archivers.tar.TarConstants;
 import org.apache.commons.compress.archivers.zip.ZipEncoding;
 import org.apache.commons.compress.archivers.zip.ZipEncodingHelper;
 import org.apache.commons.compress.compressors.CompressorException;
+import org.apache.commons.io.IOUtils;
 import org.vafer.jdeb.utils.Utils;
 
 import java.io.File;
@@ -62,7 +63,8 @@ class DataBuilder {
 
     DataBuilder(Console console, Long outputTimestampMs) {
         this.console = console;
-        this.encoding = ZipEncodingHelper.getZipEncoding(null);
+        String empty = null;
+        this.encoding = ZipEncodingHelper.getZipEncoding(empty);
         this.outputTimestampMs = outputTimestampMs;
     }
 
@@ -271,12 +273,20 @@ class DataBuilder {
             }
         };
 
+        boolean finishedWithoutErrors = true;
         try {
             for (DataProducer data : producers) {
                 data.produce(receiver);
             }
+        } catch (Exception e) {
+            finishedWithoutErrors = false;
+            throw e;
         } finally {
-            tarOutputStream.close();
+            if (finishedWithoutErrors) {
+                tarOutputStream.close();
+            } else {
+                IOUtils.closeQuietly(tarOutputStream);
+            }
         }
 
         console.debug("Total size: " + dataSize);
