@@ -1,5 +1,5 @@
 /*
- * Copyright 2007-2021 The jdeb developers.
+ * Copyright 2007-2024 The jdeb developers.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -233,12 +233,6 @@ public class DebMojo extends AbstractMojo {
     @Parameter
     private Data[] dataSet;
 
-//    /**
-//     * @deprecated
-//     */
-//    @Parameter(defaultValue = "false")
-//    private boolean timestamped;
-
     /**
      * When enabled SNAPSHOT inside the version gets replaced with current timestamp or
      * if set a value of a environment variable.
@@ -280,9 +274,7 @@ public class DebMojo extends AbstractMojo {
     @Parameter(property = "jdeb.skipSubmodules", defaultValue = "false")
     private boolean skipSubmodules;
 
-    /**
-     * @deprecated
-     */
+    @Deprecated
     @Parameter(defaultValue = "true")
     private boolean submodules;
 
