@@ -1,5 +1,5 @@
 /*
- * Copyright 2007-2021 The jdeb developers.
+ * Copyright 2007-2024 The jdeb developers.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -73,7 +73,7 @@ public final class DataBuilderTestCase extends Assert {
 
         int count = 0;
         try (TarArchiveInputStream in = new TarArchiveInputStream(new FileInputStream(archive))) {
-            while (in.getNextTarEntry() != null) {
+            while (in.getNextEntry() != null) {
                 count++;
             }
         }
