@@ -1,5 +1,5 @@
 /*
- * Copyright 2007-2021 The jdeb developers.
+ * Copyright 2007-2024 The jdeb developers.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -25,14 +25,14 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
 import org.apache.commons.compress.archivers.ar.ArArchiveEntry;
 import org.apache.commons.compress.archivers.tar.TarArchiveEntry;
-import org.apache.commons.compress.utils.IOUtils;
+import org.apache.commons.io.IOUtils;
 import org.apache.commons.io.output.NullOutputStream;
-import org.apache.commons.lang3.ArrayUtils;
 import org.apache.commons.lang3.reflect.FieldUtils;
 import org.junit.Assert;
 import org.junit.Test;
@@ -142,7 +142,7 @@ public final class DebMakerTestCase extends Assert {
                 assertTrue("prefix", entry.getName().startsWith("./"));
 
                 InformationInputStream infoStream = new InformationInputStream(new ByteArrayInputStream(content));
-                IOUtils.copy(infoStream, NullOutputStream.NULL_OUTPUT_STREAM);
+                IOUtils.copy(infoStream, NullOutputStream.INSTANCE);
 
                 if (infoStream.isShell()) {
                     assertTrue("Permissions on " + entry.getName() + " should be 755", entry.getMode() == 0755);
@@ -288,6 +288,23 @@ public final class DebMakerTestCase extends Assert {
         assertTrue("Cannot delete the file " + deb, deb.delete());
     }
 
+    @Test
+    public void testErrorPropagation() throws Exception {
+        File deb = File.createTempFile("jdeb", ".deb");
+        DebMaker maker = new DebMaker(new NullConsole(), List.of(new UseNullAsInputStream()), null);
+        maker.setControl(new File(getClass().getResource("deb/control").toURI()));
+        maker.setDeb(deb);
+
+        Exception producedException = assertThrows(PackagingException.class, () -> {
+            maker.makeDeb();
+        });
+        Throwable cause = producedException.getCause();
+        while (cause.getClass() != NullPointerException.class) {
+            cause = cause.getCause();
+            assertNotNull("expected NullPointerException cause was not found", cause);
+        }
+    }
+
     private DataProducer[] prepareData() throws URISyntaxException {
         File archive1 = new File(getClass().getResource("deb/data.tgz").toURI());
         File archive2 = new File(getClass().getResource("deb/data.tar.bz2").toURI());
@@ -314,4 +331,18 @@ public final class DebMakerTestCase extends Assert {
             assertEquals("Modified time does not match the expected value for " + entry.getName(), entry.getLastModified(), EXPECTED_MODIFIED_TIME / 1000);
         }
     }
+
+    private static class UseNullAsInputStream implements DataProducer {
+
+        @Override
+        public void produce(DataConsumer receiver) throws IOException {
+            receiver.onEachFile(null, createEntry());
+        }
+
+        private TarArchiveEntry createEntry() {
+            TarArchiveEntry entry = new TarArchiveEntry("missing_file");
+            return entry;
+        }
+    }
+
 }
